﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml.Linq;
namespace LinqTestConsole
{
    class FenixAlertNotification
    {
        public enum Notification
        {
            Tone = 0,
            Vibration = 1,
            ToneAndVib = 2,
            None = 3
        }
        public enum DistanceUnits
        {
            feet = 7,
            kilometers = 9,
            miles = 10,
            meters = 11,
            yards = 58
        }
        public enum SpeedUnits
        {
            kmPerHour = 1,
            knots = 32,
            mph = 33
        }
        public Boolean Active { get; set; }
        public Boolean Set { get; set; }
        public Int32 AlertNotification { get; set; }
        public Double Value { get; set; }
        public Int32 Units { get; set; }
        public FenixAlertNotification(Boolean p_Active, Boolean p_Set, Int32 p_AlertNotification, Double p_Value, Int32 p_Units)
        {
            Active = p_Active;
            Set = p_Set;
            AlertNotification = (Int32)p_AlertNotification;
            Value = p_Value;
            Units = p_Units;
        }

        public FenixAlertNotification()
        {
        }
        public static FenixAlertNotification GetAlertNotification(XDocument p_thisDoc, String p_sAlertName)
        {
            var thisAlertMain = (from thisAlert in p_thisDoc.Descendants(p_sAlertName)
                                 where (thisAlert as XElement) != null
                                 select new FenixAlertNotification
                                 {
                                     Active = thisAlert.Element("Active") == null ? false : (Boolean)thisAlert.Element("Active"),
                                     Set = thisAlert.Element("Set") == null ? false: (Boolean)thisAlert.Element("Set"),
                                     AlertNotification = (Int32?)thisAlert.Element("Notification") ?? 3,
                                     Value = thisAlert.Element("Value") == null ? 0 : (Double)thisAlert.Element("Value"),
                                     Units = (Int32?)thisAlert.Element("Units") ?? (Int32)FenixAlertNotification.DistanceUnits.miles
                                 });
            return thisAlertMain.First();
        }
        public XElement ToXML(String p_ElementName)
        {
            XElement outElement = new XElement(p_ElementName);
            outElement.Add(new XElement("Active", Active));
            outElement.Add(new XElement("Set", Set));
            outElement.Add(new XElement("Notification", AlertNotification));
            outElement.Add(new XElement("Value", Value));
            outElement.Add(new XElement("Units", Units));
            return outElement;
        }
    }
}
